@@ -2,17 +2,11 @@
  *
  * Copyright (c) 2003,2004 Brookhaven National  Laboratory
  *               S. Kate Feng <feng1@bnl.gov>
- * All rights reserved 
+ * All rights reserved
  *
  * Acknowledgements:
- * netBSD : Copyright (c) 2002 Allegro Networks, Inc., Wasabi Systems, Inc. 
+ * netBSD : Copyright (c) 2002 Allegro Networks, Inc., Wasabi Systems, Inc.
  * Marvell : NDA document for the discovery system controller
- * The author referenced two RTEMS network drivers of other NICs.
- * rtems : 1) dec21140.c, a network driver for for TULIP based Ethernet Controller
- *            (C) 1999 Emmanuel Raguet. raguet@crf.canon.fr
- *
- *         2) yellowfin.c, a network driver for the SVGM5 BSP.
- *           Stanford Linear Accelerator Center, Till Straumann 
  *
  * Some notes from the author, S. Kate Feng :
  *
@@ -22,7 +16,7 @@
  * 2) Implemented hardware snoop instead of software snoop
  *    to ensure SDRAM cache coherency. (Copyright : NDA item)
  * 3) Added S/W support for multi mbuf.  (TODO : Let the H/W do it)
- *    
+ *
  */
 #define BYTE_ORDER BIG_ENDIAN
 
@@ -43,12 +37,12 @@
 
 #include <rtems/rtems_bsdnet.h>
 #include <rtems/rtems_bsdnet_internal.h>
-#include <rtems/error.h>           
+#include <rtems/error.h>
 #include <errno.h>
 
 #include <rtems/rtems/types.h>
 
-#include <sys/queue.h>
+/* #include <sys/queue.h> */
 
 #include <sys/ioctl.h>
 #include <sys/socket.h>
@@ -67,14 +61,16 @@
 #include <bsp/GT64260eth.h>
 #include <bsp/VPD.h>
 
+extern unsigned char ReadConfVPD_buff(int offset); /* in startup/bspstart.c */
+
 #define GT_ETH_TASK_NAME  "Geth"
 #define PKT_BUF_SZ 1536
-#define SOFTC_ALIGN  31   
-#define HASH_ALIGN   15   
+#define SOFTC_ALIGN  31
+#define HASH_ALIGN   15
 
 #define TXQ_HiLmt_OFF 2
 
-/* <skf> 
+/* <skf>
  * 1. printk debug is for diagnosis only, which may cause
  * unexpected result, especially if txq is under heavy load
  * because CPU is fast with a decent cache.
@@ -85,7 +81,7 @@
 #if 0
 #define GE_FORGOT
 #define GE_NORX
-#define GT_DEBUG 
+#define GT_DEBUG
 #endif
 
 /* RTEMS event to kill the daemon */
@@ -110,7 +106,7 @@ enum GTeth_hash_op {
 
 #define	ET_MINLEN 64		/* minimum message length */
 
-static int GTeth_ifioctl(struct ifnet *ifp, u_long cmd, caddr_t data);
+static int GTeth_ifioctl(struct ifnet *ifp, ioctl_command_t cmd, caddr_t data);
 static void GTeth_ifstart (struct ifnet *);
 static void GTeth_ifchange(struct GTeth_softc *sc);
 static void GTeth_init_rx_ring(struct GTeth_softc *sc);
@@ -125,7 +121,7 @@ static int GT64260eth_rx(struct GTeth_softc *sc);
 static void GTeth_rx_setup(struct GTeth_softc *sc);
 static void GTeth_rxprio_setup(struct GTeth_softc *sc);
 static void GTeth_rx_stop(struct GTeth_softc *dc);
-static void GT64260eth_isr();
+static void GT64260eth_isr(void);
 static int GTeth_hash_compute(struct GTeth_softc *sc,unsigned char eaddr[ETHER_ADDR_LEN]);
 static int GTeth_hash_entry_op(struct GTeth_softc *sc, enum GTeth_hash_op op,
 	enum GTeth_rxprio prio,unsigned char eaddr[ETHER_ADDR_LEN]);
@@ -142,7 +138,7 @@ static void GT64260eth_irq_on(const rtems_irq_connect_data *irq)
   for (sc= root_GT64260eth_dev; sc; sc= sc-> next_module) {
     outl(0x30883444,ETH0_EIMR); /* MOTLoad default interrupt mask */
     return;
-  }  
+  }
 }
 
 static void GT64260eth_irq_off(const rtems_irq_connect_data *irq)
@@ -158,7 +154,7 @@ static int GT64260eth_irq_is_on(const rtems_irq_connect_data *irq)
   return(inl(ETH0_EICR) & ETH_IR_EtherIntSum);
 }
 
-static void GT64260eth_isr()
+static void GT64260eth_isr(void)
 {
   struct GTeth_softc *sc = root_GT64260eth_dev;
   rtems_event_set  events=0;
@@ -172,7 +168,7 @@ static void GT64260eth_isr()
        sc->intr_errsts[sc->intr_err_ptr2++]=cause;
        sc->intr_err_ptr2 %=INTR_ERR_SIZE;   /* Till Straumann */
        events |= ERR_EVENT;
-  }  
+  }
 
   /* ETH_IR_RxBuffer_3|ETH_IR_RxError_3 */
   if (cause & 0x880000) {
@@ -204,7 +200,7 @@ static rtems_irq_connect_data GT64260ethIrqData={
         NULL,
 	(rtems_irq_enable) GT64260eth_irq_on,
 	(rtems_irq_disable) GT64260eth_irq_off,
-	(rtems_irq_is_enabled) GT64260eth_irq_is_on, 
+	(rtems_irq_is_enabled) GT64260eth_irq_is_on,
 };
 
 static void GT64260eth_init_hw(struct GTeth_softc *sc)
@@ -221,7 +217,7 @@ static void GT64260eth_init_hw(struct GTeth_softc *sc)
 
   sc->rxq_intrbits=0;
   sc->sc_flags=0;
-  
+
 #ifndef GE_NORX
   GTeth_rx_setup(sc);
 #endif
@@ -252,7 +248,7 @@ static void GT64260eth_init_hw(struct GTeth_softc *sc)
    */
   if (!BSP_install_rtems_irq_handler(&GT64260ethIrqData))
      printk("GT64260eth: unable to install ISR");
-   
+
   /* The ethernet port is ready to transmit/receive */
   outl(sc->sc_pcr | ETH_EPCR_EN, ETH0_EPCR);
 
@@ -323,8 +319,8 @@ static void GT64260eth_ifinit(void *arg)
   }
 
 #ifndef GE_NOHASH
-  /* Mvme5500, the user must initialize the hash table before enabling the 
-   * Ethernet controller 
+  /* Mvme5500, the user must initialize the hash table before enabling the
+   * Ethernet controller
    */
   GTeth_hash_init(sc);
   GTeth_hash_fill(sc);
@@ -364,10 +360,9 @@ int rtems_GT64260eth_driver_attach(struct rtems_bsdnet_ifconfig *config, int att
 
   unit = rtems_bsdnet_parse_driver_name(config, &name);
   if (unit < 0) return 0;
- 
-  printk("\nEthernet driver name %s unit %d \n",name, unit);
-  printk("(c) 2004, Brookhaven National Lab. <feng1@bnl.gov> (RTEMS/mvme5500 port)\n");
 
+  printk("\nEthernet driver name %s unit %d \n",name, unit);
+  printk("RTEMS-mvme5500 BSP Copyright (c) 2004, Brookhaven National Lab., Shuchen Kate Feng \n");
   /* Make certain elements e.g. descriptor lists are aligned. */
   softc_mem = rtems_bsdnet_malloc(sizeof(*sc) + SOFTC_ALIGN, M_FREE, M_NOWAIT);
 
@@ -393,7 +388,7 @@ int rtems_GT64260eth_driver_attach(struct rtems_bsdnet_ifconfig *config, int att
   } else {
     printk("Read EEPROM ");
      for (i = 0; i < 6; i++)
-       hwaddr[i] = ConfVPD_buff[VPD_ENET0_OFFSET+i];
+       hwaddr[i] = ReadConfVPD_buff(VPD_ENET0_OFFSET+i);
   }
 
 #ifdef GT_DEBUG
@@ -486,7 +481,7 @@ int rtems_GT64260eth_driver_attach(struct rtems_bsdnet_ifconfig *config, int att
   /*  ifp->if_watchdog = GTeth_ifwatchdog;*/
 
   if (ifp->if_snd.ifq_maxlen == 0)
-    ifp->if_snd.ifq_maxlen = ifqmaxlen; 
+    ifp->if_snd.ifq_maxlen = ifqmaxlen;
 
   /* create the synchronization semaphore */
   if (RTEMS_SUCCESSFUL != rtems_semaphore_create(
@@ -509,16 +504,16 @@ int rtems_GT64260eth_driver_attach(struct rtems_bsdnet_ifconfig *config, int att
 
 static void GT64260eth_stats(struct GTeth_softc *sc)
 {
+#if 0
   struct ifnet *ifp = &sc->arpcom.ac_if;
 
-#if 0
   printf("       Rx Interrupts:%-8lu\n", sc->stats.rxInterrupts);
   printf("     Receive Packets:%-8lu\n", ifp->if_ipackets);
   printf("     Receive  errors:%-8lu\n", ifp->if_ierrors);
   printf("      Framing Errors:%-8lu\n", sc->stats.frame_errors);
   printf("          Crc Errors:%-8lu\n", sc->stats.crc_errors);
   printf("    Oversized Frames:%-8lu\n", sc->stats.length_errors);
-  printf("         Active Rxqs:%-8u\n",  sc->rxq_active); 
+  printf("         Active Rxqs:%-8u\n",  sc->rxq_active);
   printf("       Tx Interrupts:%-8lu\n", sc->stats.txInterrupts);
 #endif
   printf("Multi-BuffTx Packets:%-8lu\n", sc->stats.txMultiBuffPacket);
@@ -530,16 +525,16 @@ static void GT64260eth_stats(struct GTeth_softc *sc)
   printf("   Transmitt Packets:%-8lu\n", ifp->if_opackets);
   printf("   Transmitt  errors:%-8lu\n", ifp->if_oerrors);
   printf("    Tx/Rx collisions:%-8lu\n", ifp->if_collisions);
-  printf("         Active Txqs:%-8u\n", sc->txq_nactive); 
+  printf("         Active Txqs:%-8u\n", sc->txq_nactive);
 #endif
 }
 
-void GT64260eth_printStats()
+void GT64260eth_printStats(void)
 {
   GT64260eth_stats(root_GT64260eth_dev);
 }
 
-static int GTeth_ifioctl(struct ifnet *ifp, u_long cmd, caddr_t data)
+static int GTeth_ifioctl(struct ifnet *ifp, ioctl_command_t cmd, caddr_t data)
 {
   struct GTeth_softc *sc = ifp->if_softc;
   struct ifreq *ifr = (struct ifreq *) data;
@@ -600,7 +595,7 @@ static int GTeth_ifioctl(struct ifnet *ifp, u_long cmd, caddr_t data)
 
 #ifdef GT_DEBUG
   printk("exit ioctl\n");
-#endif	
+#endif
   return error;
 }
 
@@ -615,7 +610,7 @@ static void GTeth_ifstart(struct ifnet *ifp)
   if ((ifp->if_flags & IFF_RUNNING) == 0) {
 #ifdef GT_DEBUG
      printk("IFF_RUNNING==0\n");
-#endif		
+#endif
      return;
   }
 
@@ -649,7 +644,7 @@ static void GTeth_init_rx_ring(struct GTeth_softc *sc)
 
   for (i = 0; i < RX_RING_SIZE; i++, rxd++, nxtaddr += sizeof(*rxd)) {
     struct mbuf *m;
- 
+
     rxd->ed_lencnt= sc->rx_buf_sz <<16;
     rxd->ed_cmdsts = RX_CMD_F|RX_CMD_L|RX_CMD_O|RX_CMD_EI;
 
@@ -658,7 +653,7 @@ static void GTeth_init_rx_ring(struct GTeth_softc *sc)
     m->m_pkthdr.rcvif =  &sc->arpcom.ac_if;
     sc->rxq_mbuf[i] = m;
 
-    /* convert mbuf pointer to data pointer of correct type */	
+    /* convert mbuf pointer to data pointer of correct type */
     rxd->ed_bufptr = (unsigned) mtod(m, void *);
 
     /*
@@ -711,23 +706,23 @@ static int GT64260eth_rx(struct GTeth_softc *sc)
     byteCount = rxd->ed_lencnt & 0xffff;
 
     if (cmdsts & RX_CMD_O) {
-      if (byteCount == 0) 
+      if (byteCount == 0)
          return(0);
 
      /* <Kate Feng> Setting command/status to be zero seems to eliminate
       * the spurious interrupt associated with the GE_FORGOT issue.
       */
-      rxd->ed_cmdsts=0; 
+      rxd->ed_cmdsts=0;
 
 #ifdef GE_FORGOT
-      /* 
+      /*
        * For dignosis purpose only. Not a good practice to turn it on
        */
       printk("Rxq %d %d %d\n", sc->rxq_fi, byteCount,nloops);
 #endif
     }
 
-    /* GT gave the ownership back to the CPU or the length has 
+    /* GT gave the ownership back to the CPU or the length has
      * been rewritten , which means there
      * is new packet in the descriptor/buffer
      */
@@ -750,25 +745,26 @@ static int GT64260eth_rx(struct GTeth_softc *sc)
         if (cmdsts & RX_STS_SF) sc->stats.frame_errors++;
         if ((cmdsts & RX_STS_LC) || (cmdsts & RX_STS_COL))
            ifp->if_collisions++;
-        goto give_it_back;
+        /* recycle the buffer */
+        m->m_len=sc->rx_buf_sz;        
+    }
+    else {
+        m = sc->rxq_mbuf[sc->rxq_fi];
+        m->m_len = m->m_pkthdr.len = byteCount - sizeof(struct ether_header);
+        eh = mtod (m, struct ether_header *);
+        m->m_data += sizeof(struct ether_header);
+        ether_input (ifp, eh, m);
+
+        ifp->if_ipackets++;
+        ifp->if_ibytes+=byteCount;
+        --sc->rxq_active;
+        MGETHDR (m, M_WAIT, MT_DATA);
+        MCLGET (m, M_WAIT);
      }
-     m = sc->rxq_mbuf[sc->rxq_fi];
-     m->m_len = m->m_pkthdr.len = byteCount - sizeof(struct ether_header);
-     eh = mtod (m, struct ether_header *);
-     m->m_data += sizeof(struct ether_header);
-     ether_input (ifp, eh, m);
-
-     ifp->if_ipackets++;
-     ifp->if_ibytes+=byteCount;
-     --sc->rxq_active;
-
-     give_it_back:
-     MGETHDR (m, M_WAIT, MT_DATA);
-     MCLGET (m, M_WAIT);
      m->m_pkthdr.rcvif = ifp;
      sc->rxq_mbuf[sc->rxq_fi]= m;
-     /* convert mbuf pointer to data pointer of correct type */	
-     rxd->ed_bufptr = (unsigned) mtod(m, void*); 
+     /* convert mbuf pointer to data pointer of correct type */
+     rxd->ed_bufptr = (unsigned) mtod(m, void*);
      rxd->ed_lencnt = (unsigned long) sc->rx_buf_sz <<16;
      rxd->ed_cmdsts = RX_CMD_F|RX_CMD_L|RX_CMD_O|RX_CMD_EI;
 
@@ -796,7 +792,7 @@ static void GTeth_rx_setup(struct GTeth_softc *sc)
      outl( sc->rxq_desc_busaddr,ETH0_ECRDP3);
 #ifdef GT_DEBUG
      printk("ETH0_EFRDP3 0x%x, ETH0_ECRDP3 0x%x \n", inl(ETH0_EFRDP3),
-	    inl(ETH0_ECRDP3)); 
+	    inl(ETH0_ECRDP3));
 #endif
   }
   sc->sc_intrmask |= sc->rxq_intrbits;
@@ -862,6 +858,7 @@ static void GTeth_txq_free(struct GTeth_softc *sc, unsigned cmdsts)
   --sc->txq_nactive;
 }
 
+#if UNUSED
 static int txq_high_limit(struct GTeth_softc *sc)
 {
   /*
@@ -901,6 +898,9 @@ static int txq_high_limit(struct GTeth_softc *sc)
   } /* end if ( TX_RING_SIZE == sc->txq_nactive + TXQ_HiLmt_OFF) */
   return 0;
 }
+#endif
+
+#define MAX(a,b) (((a) > (b)) ? (a) : (b))
 
 static int GT64260eth_sendpacket(struct GTeth_softc *sc,struct mbuf *m)
 {
@@ -908,7 +908,7 @@ static int GT64260eth_sendpacket(struct GTeth_softc *sc,struct mbuf *m)
   unsigned intrmask = sc->sc_intrmask;
   unsigned loop=0, index= sc->txq_lo;
 
-  /* 
+  /*
    * The end-of-list descriptor we put on last time is the starting point
    * for this packet.  The GT is supposed to terminate list processing on
    * a NULL nxtptr but that currently is broken so a CPU-owned descriptor
@@ -921,14 +921,14 @@ static int GT64260eth_sendpacket(struct GTeth_softc *sc,struct mbuf *m)
     sc->stats.txSinglMaxLen= MAX(m->m_len, sc->stats.txSinglMaxLen);
   }
   else /* multiple mbufs in this packet */
-  { 
+  {
     struct mbuf *mtp, *mdest;
     volatile unsigned char *pt;
     int len, y;
 
 #ifdef GT_DEBUG
     printk("multi mbufs ");
-#endif    
+#endif
     MGETHDR(mdest, M_WAIT, MT_DATA);
     MCLGET(mdest, M_WAIT);
     pt = (volatile unsigned char *)mdest->m_data;
@@ -936,9 +936,9 @@ static int GT64260eth_sendpacket(struct GTeth_softc *sc,struct mbuf *m)
       loop++;
       if ( (y=(len+mtp->m_len)) > sizeof(union mcluster)) {
 	/* GT64260 allows us to chain the remaining to the next
-         * free descriptors. 
+         * free descriptors.
          */
-        printk("packet size %x > mcluster %x\n", y,sizeof(union mcluster)); 
+        printk("packet size %x > mcluster %x\n", y,sizeof(union mcluster));
 	printk("GT64260eth : packet too large ");
       }
       memcpy((void *)pt,(char *)mtp->m_data, mtp->m_len);
@@ -947,7 +947,7 @@ static int GT64260eth_sendpacket(struct GTeth_softc *sc,struct mbuf *m)
     printk("%d ",mtp->m_len);
 #endif
       len += mtp->m_len;
-      sc->stats.txBuffMaxLen=MAX(mtp->m_len,sc->stats.txBuffMaxLen); 
+      sc->stats.txBuffMaxLen=MAX(mtp->m_len,sc->stats.txBuffMaxLen);
     }
     sc->stats.txMultiMaxLoop=MAX(loop, sc->stats.txMultiMaxLoop);
 #if 0
@@ -962,14 +962,14 @@ static int GT64260eth_sendpacket(struct GTeth_softc *sc,struct mbuf *m)
   }
   if (m->m_len < ET_MINLEN) m->m_len = ET_MINLEN;
 
-  txd->ed_bufptr = (unsigned) mtod(m, void*); 
+  txd->ed_bufptr = (unsigned) mtod(m, void*);
   txd->ed_lencnt = m->m_len << 16;
   /*txd->ed_cmdsts = TX_CMD_L|TX_CMD_GC|TX_CMD_P|TX_CMD_O|TX_CMD_F|TX_CMD_EI;*/
   txd->ed_cmdsts = 0x80c70000;
   while (txd->ed_cmdsts != 0x80c70000);
   memBar();
 
-#ifdef GT_DEBUG 
+#ifdef GT_DEBUG
   printk("len = %d, cmdsts 0x%x ", m->m_len,txd->ed_cmdsts);
 #endif
 
@@ -1043,10 +1043,10 @@ static unsigned GTeth_txq_done(struct GTeth_softc *sc)
 	*/
        nextin = (sc->txq_fi + 1) % TX_RING_SIZE;
 
-       if (sc->txq_desc[nextin].ed_cmdsts & TX_CMD_O) return(0); 
+       if (sc->txq_desc[nextin].ed_cmdsts & TX_CMD_O) return(0);
        printk("Txq%d forgot\n",sc->txq_fi);
     } /* end checking GT64260eth owner */
-    GTeth_txq_free(sc, cmdsts);   
+    GTeth_txq_free(sc, cmdsts);
   }  /* end while */
   if (GTeth_debug>0) printk(")\n");
   return(1);
@@ -1098,7 +1098,7 @@ static void GTeth_tx_start(struct GTeth_softc *sc)
       printk("next desc. @ 0x%x\n",txd->ed_nxtptr);
 #endif
   }
- 
+
   sc->txq_intrbits = ETH_IR_TxEndHigh|ETH_IR_TxBufferHigh;
   sc->txq_esdcmrbits = ETH_ESDCMR_TXDH; /* Start Tx high */
   sc->txq_epsrbits = ETH_EPSR_TxHigh;
@@ -1137,7 +1137,6 @@ static void GTeth_tx_stop(struct GTeth_softc *sc)
   sc->arpcom.ac_if.if_timer = 0;
 }
 
-/* TOCHECK : Should it be about rx or tx ? */
 static void GTeth_ifchange(struct GTeth_softc *sc)
 {
   if (GTeth_debug>0) printk("GTeth_ifchange(");
@@ -1177,7 +1176,7 @@ static int GTeth_hash_compute(struct GTeth_softc *sc,unsigned char eaddr[ETHER_A
 #ifdef GT_DEBUG
   printk("eaddr= %s add1:%x add0:%x\n", ether_sprintf1(eaddr), add1, add0);
 #endif
-    
+
   /*
    * hashResult is the 15 bits Hash entry address.
    * ethernetADD is a 48 bit number, which is derived from the Ethernet
@@ -1233,8 +1232,8 @@ static int GTeth_hash_compute(struct GTeth_softc *sc,unsigned char eaddr[ETHER_A
   printk(")");
 #endif
 
-  /* 1/2K address filtering (MOTLoad default )? ->16KB memory required 
-   * or 8k address filtering ? -> 256KB memory required 
+  /* 1/2K address filtering (MOTLoad default )? ->16KB memory required
+   * or 8k address filtering ? -> 256KB memory required
    */
   return result & ((sc->sc_pcr & ETH_EPCR_HS_512) ? 0x7ff : 0x7fff);
 }
@@ -1292,7 +1291,7 @@ static int GTeth_hash_entry_op(struct GTeth_softc *sc, enum GTeth_hash_op op,
   for (limit = HSH_LIMIT; limit > 0 ; --limit) {
       /*
        * Does the GT wrap at the end, stop at the, or overrun the
-       * end?  Assume it wraps for now.  Stash a copy of the 
+       * end?  Assume it wraps for now.  Stash a copy of the
        * current hash entry.
        */
       unsigned long long *he_p = &sc->sc_hashtable[hash];
@@ -1338,7 +1337,7 @@ static int GTeth_hash_entry_op(struct GTeth_softc *sc, enum GTeth_hash_op op,
        if (maybe_he_p == NULL && (thishe & HSH_S)) {
 	  maybe_he_p = he_p;
 	  maybe_hash = hash;
-       }		
+       }
        hash = (hash + 1) & (sc->sc_hashmask / sizeof(he));
   }
 
@@ -1427,7 +1426,7 @@ static void GTeth_hash_init(struct GTeth_softc *sc)
 
   if (GTeth_debug>0) printk("GTeth_hash_init(");
   /* MOTLoad defualt : 512 bytes of address filtering, which
-   * requires 16KB of memory 
+   * requires 16KB of memory
    */
 #if 1
   hash_mem = rtems_bsdnet_malloc(HASH_DRAM_SIZE + HASH_ALIGN, M_FREE, M_NOWAIT);
@@ -1445,6 +1444,7 @@ static void GTeth_hash_init(struct GTeth_softc *sc)
 #endif
 }
 
+#ifdef GT64260eth_DEBUG
 static void GT64260eth_error(struct GTeth_softc *sc)
 {
   struct ifnet	        *ifp = &sc->arpcom.ac_if;
@@ -1454,7 +1454,7 @@ static void GT64260eth_error(struct GTeth_softc *sc)
    * by the ISR, we must disable interrupts here
    */
   if (intr_status) {
-    printk("%s%d: ICR = 0x%x ", 
+    printk("%s%d: ICR = 0x%x ",
 	   ifp->if_name, ifp->if_unit, intr_status);
 #if 1
     if (intr_status & INTR_RX_ERROR) {
@@ -1468,13 +1468,13 @@ static void GT64260eth_error(struct GTeth_softc *sc)
        printk("Txq error,  if_oerrors %d\n",ifp->if_oerrors);
     }
   }
-  else 
+  else
     printk("%s%d: Ghost interrupt ?\n",ifp->if_name,
 	   ifp->if_unit);
-  sc->intr_errsts[sc->intr_err_ptr1++]=0;  
+  sc->intr_errsts[sc->intr_err_ptr1++]=0;
   sc->intr_err_ptr1 %= INTR_ERR_SIZE;   /* Till Straumann */
 }
-
+#endif
 
 /* The daemon does all of the work; RX, TX and cleaning up buffers/descriptors */
 static void GT64260eth_daemon(void *arg)
@@ -1484,7 +1484,7 @@ static void GT64260eth_daemon(void *arg)
   struct mbuf	*m=0;
   struct ifnet	*ifp=&sc->arpcom.ac_if;
 
-#if 0	
+#if 0
   /* see comments in GT64260eth_init(); in newer versions of
    * rtems, we hold the network semaphore at this point
    */
@@ -1510,7 +1510,7 @@ static void GT64260eth_daemon(void *arg)
 				RTEMS_WAIT | RTEMS_EVENT_ANY,
 				RTEMS_NO_TIMEOUT,
 				&events);
- 
+
      if (KILL_EVENT & events) break;
 
 #ifndef GE_NORX
@@ -1522,7 +1522,7 @@ static void GT64260eth_daemon(void *arg)
 #endif
 
      /* clean up and try sending packets */
-     do { 
+     do {
 	 if (sc->txq_nactive) GTeth_txq_done(sc);
 
          while (sc->txq_free>0) {
@@ -1530,7 +1530,7 @@ static void GT64260eth_daemon(void *arg)
 	      m=0;
 	      IF_DEQUEUE(&ifp->if_snd,m);
               if (m==0) break;
-              GT64260eth_sendpacket(sc, m); 
+              GT64260eth_sendpacket(sc, m);
            }
            else {
               GTeth_txq_done(sc);
@@ -1548,7 +1548,9 @@ static void GT64260eth_daemon(void *arg)
        ifp->if_flags &= ~IFF_OACTIVE;
 
        /* Log errors and other uncommon events. */
-       if (events & ERR_EVENT) GT64260eth_error(sc); 
+#ifdef GT64260eth_DEBUG
+       if (events & ERR_EVENT) GT64260eth_error(sc);
+#endif
   } /* end for(;;) { rtems_bsdnet_event_receive() .....*/
 
   ifp->if_flags &= ~(IFF_RUNNING|IFF_OACTIVE);
@@ -1567,7 +1569,7 @@ static void GT64260eth_daemon(void *arg)
   rtems_bsdnet_semaphore_release();
   rtems_semaphore_release(sc->daemonSync);
 
-  /* Note that I dont use sc->daemonTid here - 
+  /* Note that I dont use sc->daemonTid here -
    * theoretically, that variable could already
    * hold a newly created TID
    */
