@@ -125,7 +125,7 @@ if (DEBUG_OUT >= (LVL)) {                                    \
 
 #define NFXPDRIVER 1
 static struct fxp_softc fxp_softc[NFXPDRIVER];
-static int fxp_is_verbose = TRUE;
+static bool fxp_is_verbose = true;
 /*
  * NOTE!  On the Alpha, we have an alignment constraint.  The
  * card DMAs the packet immediately following the RFA.  However,
@@ -452,21 +452,21 @@ rtems_fxp_attach(struct rtems_bsdnet_ifconfig *config, int attaching)
     { int j; int pbus, pdev, pfun;
 
       for (j=0; fxp_ident_table[j].devid; j++ ) {
-		i = pci_find_device( 0x8086, fxp_ident_table[j].devid,
-			unitNumber-1, &pbus, &pdev, &pfun );
- 		sc->pci_signature =  PCIB_DEVSIG_MAKE( pbus, pdev, pfun );
-		DBGLVL_PRINTK(2,"fxp_attach: find_devid returned %d "
+		    i = pci_find_device( 0x8086, fxp_ident_table[j].devid,
+			       unitNumber-1, &pbus, &pdev, &pfun );
+ 		    sc->pci_signature =  PCIB_DEVSIG_MAKE( pbus, pdev, pfun );
+		    DBGLVL_PRINTK(2,"fxp_attach: find_devid returned %d "
 		      "and pci signature 0x%x\n",
 		      i,sc->pci_signature);
-        	if (PCIB_ERR_SUCCESS == i) {
-		  if ( UNTESTED == fxp_ident_table[j].warn ) {
-		  	device_printf(dev,
+      	if (PCIB_ERR_SUCCESS == i) {
+		    if ( UNTESTED == fxp_ident_table[j].warn ) {
+		  	  device_printf(dev,
 "WARNING: this chip version has NOT been reported to work under RTEMS yet.\n");
-			device_printf(dev,
+			    device_printf(dev,
 "         If it works OK, report it as tested in 'c/src/libchip/network/if_fxp.c'\n");
-			}
+			  }
   			break;
-		}
+		  }
 	  }
 	}
 
@@ -561,14 +561,14 @@ rtems_fxp_attach(struct rtems_bsdnet_ifconfig *config, int attaching)
 	pcib_conf_read16(sc->pci_signature, PCI_COMMAND,&val16);
 	DBGLVL_PRINTK(4,"fxp_attach: PCI_COMMAND_read  = 0x%x\n",val16);
 	if((val16 & PCI_COMMAND_IO) != 0) {
-	  sc->pci_regs_are_io = TRUE;
+	  sc->pci_regs_are_io = true;
 	  pcib_conf_read32(sc->pci_signature,
 			   PCI_BASE_ADDRESS_1,
 			   &val32);
 	  sc->pci_regs_base = val32 & PCI_BASE_ADDRESS_IO_MASK;
 	}
 	else {
-	  sc->pci_regs_are_io = FALSE;
+	  sc->pci_regs_are_io = false;
 	  pcib_conf_read32(sc->pci_signature,
 			   PCI_BASE_ADDRESS_0,
 			   &val32);
