@@ -69,6 +69,9 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
 #include <netdb.h>
 #include <resolv.h>
 #include <ctype.h>
@@ -119,9 +122,9 @@ int _dns_ttl_;
 
 #ifdef DEBUG
 static void
-debugprintf(msg, num)
-	char *msg;
-	int num;
+debugprintf(
+	char *msg,
+	int num)
 {
 	if (_res.options & RES_DEBUG) {
 		int save = errno;
@@ -152,11 +155,11 @@ debugprintf(msg, num)
 	} while (0)
 
 static struct hostent *
-gethostanswer(answer, anslen, qname, qtype)
-	const querybuf *answer;
-	int anslen;
-	const char *qname;
-	int qtype;
+gethostanswer(
+	const querybuf *answer,
+	int anslen,
+	const char *qname,
+	int qtype)
 {
 	const HEADER *hp;
 	const u_char *cp;
@@ -390,7 +393,7 @@ gethostanswer(answer, anslen, qname, qtype)
 				buflen -= nn;
 			}
 
-			bp += sizeof(align) - ((u_long)bp % sizeof(align));
+			bp += sizeof(align) - ((uintptr_t)bp % sizeof(align));
 
 			if (bp + n >= &hostbuf[sizeof hostbuf]) {
 				debugprintf("size (%d) too big\n", n);
@@ -472,9 +475,9 @@ __dns_getanswer(const char *answer, int anslen, const char *qname, int qtype)
 }
 
 struct hostent *
-_gethostbydnsname(name, af)
-	const char *name;
-	int af;
+_gethostbydnsname(
+	const char *name,
+	int af)
 {
 	querybuf buf;
 	register const char *cp;
@@ -516,7 +519,7 @@ _gethostbydnsname(name, af)
 	 * disallow names consisting only of digits/dots, unless
 	 * they end in a dot.
 	 */
-	if (isdigit((int)name[0]))
+	if (isdigit((unsigned char)name[0]))
 		for (cp = name;; ++cp) {
 			if (!*cp) {
 				if (*--cp == '.')
@@ -545,10 +548,10 @@ _gethostbydnsname(name, af)
 				h_errno = NETDB_SUCCESS;
 				return (&host);
 			}
-			if (!isdigit((int)*cp) && *cp != '.') 
+			if (!isdigit((unsigned char)*cp) && *cp != '.') 
 				break;
 		}
-	if ((isxdigit((int)name[0]) && strchr(name, ':') != NULL) ||
+	if ((isxdigit((unsigned char)name[0]) && strchr(name, ':') != NULL) ||
 	    name[0] == ':')
 		for (cp = name;; ++cp) {
 			if (!*cp) {
@@ -576,7 +579,7 @@ _gethostbydnsname(name, af)
 				h_errno = NETDB_SUCCESS;
 				return (&host);
 			}
-			if (!isxdigit((int)*cp) && *cp != ':' && *cp != '.') 
+			if (!isxdigit((unsigned char)*cp) && *cp != ':' && *cp != '.') 
 				break;
 		}
 
@@ -588,9 +591,10 @@ _gethostbydnsname(name, af)
 }
 
 struct hostent *
-_gethostbydnsaddr(addr, len, af)
-	const char *addr;	/* XXX should have been def'd as u_char! */
-	int len, af;
+_gethostbydnsaddr(
+	const char *addr,	/* XXX should have been def'd as u_char! */
+	int len, 
+	int af)
 {
 	const u_char *uaddr = (const u_char *)addr;
 	static const u_char mapped[] = { 0,0, 0,0, 0,0, 0,0, 0,0, 0xff,0xff };
@@ -711,9 +715,9 @@ _gethostbydnsaddr(addr, len, af)
 
 #ifdef RESOLVSORT
 static void
-addrsort(ap, num)
-	char **ap;
-	int num;
+addrsort(
+	char **ap,
+	int num)
 {
 	int i, j;
 	char **p;
@@ -764,7 +768,7 @@ _sethostdnsent(int stayopen)
 }
 
 void
-_endhostdnsent()
+_endhostdnsent(void)
 {
 	_res.options &= ~(RES_STAYOPEN | RES_USEVC);
 	res_close();
