@@ -1,14 +1,14 @@
 /*
  *  3.3.2 Send a Signal to a Process, P1003.1b-1993, p. 68
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2007.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: kill.c,v 1.5 2004/04/15 13:24:47 ralf Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -30,22 +30,3 @@ int kill(
   return killinfo( pid, sig, NULL );
 }
 
-/*
- *  _kill_r
- *
- *  This is the Newlib dependent reentrant version of kill().
- */
-
-#if defined(RTEMS_NEWLIB)
-
-#include <reent.h>
-
-int _kill_r(
-  struct _reent *ptr,
-  pid_t          pid,
-  int            sig
-)
-{
-  return kill( pid, sig );
-}
-#endif
