@@ -1,14 +1,14 @@
 /*
  *  20.1.6 Accessing a Thread CPU-time Clock, P1003.4b/Draft 8, p. 58
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2007.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: pthreadgetcpuclockid.c,v 1.6 2004/04/15 13:24:47 ralf Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -19,11 +19,12 @@
 #include <errno.h>
 
 #include <rtems/system.h>
+#include <rtems/seterr.h>
 
 int pthread_getcpuclockid(
   pthread_t    pid,
   clockid_t   *clock_id
 )
 {
-  return POSIX_NOT_IMPLEMENTED();
+  rtems_set_errno_and_return_minus_one( ENOSYS );
 }
