@@ -23,7 +23,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: types.h,v 1.11 2006/11/17 05:58:01 ralf Exp $
+ *  $Id$
  */
 
 #ifndef _RTEMS_SCORE_TYPES_H
@@ -31,7 +31,8 @@
 
 #ifndef ASM
 
-#include <rtems/stdint.h>
+#include <stdbool.h>
+#include <stdint.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -43,15 +44,15 @@ extern "C" {
 
 typedef uint16_t     Priority_Bit_map_control;
 
-typedef uint16_t boolean;	     		/* Boolean value, external */
-						/* data bus has 16 bits  */
-
-typedef float          single_precision;     	/* single precision float */
-typedef double         double_precision;     	/* double precision float */
-
 typedef void sh_isr;
 typedef void ( *sh_isr_entry )( void );
 
+#ifdef RTEMS_DEPRECATED_TYPES
+typedef bool boolean;	     			/* Boolean value, external */
+typedef float          single_precision;     	/* single precision float */
+typedef double         double_precision;     	/* double precision float */
+#endif
+
 #ifdef __cplusplus
 }
 #endif
