@@ -10,27 +10,38 @@
  *
  *  Output parameters:  NONE
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2008.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: init.cc,v 1.1 2004/05/10 15:59:59 ralf Exp $
+ *  $Id$
  */
 
 #define CONFIGURE_INIT
 #include "system.h"
 
+#if BSP_SMALL_MEMORY
+#include <stdio.h>
+#else
 #include <iostream>
+#endif
+
+#include <stdlib.h>
 
 rtems_task Init(
   rtems_task_argument ignored
 )
 {
+#if BSP_SMALL_MEMORY
+  printf ("NO STDC++. MEMORY TOO SMALL");
+#else
   std::cout << "\n\n*** HELLO WORLD TEST ***" << std::endl;
   std::cout << "Hello World" << std::endl;
   std::cout << "*** END OF HELLO WORLD TEST ***" << std::endl;
+#endif
   exit( 0 );
 }
+
